@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------
 // This file is part of AROUNDMe
 //
-// Copyright (C) 2003 - 2006 Barnraiser
+// Copyright (C) 2003 - 2007 Barnraiser
 // http://www.barnraiser.org/
 // info@barnraiser.org
 //
@@ -75,17 +75,30 @@ class Event {
 		$rec['event_create_datetime'] = time();
 		$rec['event_start_datetime']  = $this->timestamps['event_start_datetime'];
 		$rec['event_end_datetime']    = $this->timestamps['event_end_time'];
-		$rec['event_title']           = $data['event_title'];
-		$rec['event_synopsis']        = $data['event_synopsis'];
+		$rec['event_title']           = trim(strip_tags($data['event_title']));
+		$rec['event_synopsis']        = trim(strip_tags($data['event_synopsis']));
 		$rec['event_body']            = $data['event_body'];
 		$rec['location_id']           = $data['location_id'];
 		$rec['user_id']               = $this->user_id;
  		$rec['status_id']             = $this->event_config['event_invite_status'];
  		$rec['event_allocation']      = $data['event_allocation'];
 		$rec['level_id']              = $data['event_invite_type'];
-		$rec['event_venue']           = $data['event_venue'];
+		$rec['event_venue']           = trim(strip_tags($data['event_venue']));
 		$rec['language_id']           = $this->language_id;
 		$rec['event_type']            = $data['participation_type'];
+		$rec['default_user_permission']= $this->event_config['default_participation_permission'];
+		
+		if (empty($rec['event_title'])) {
+			$GLOBALS['am_error_log'][] = array('no_title');
+		}
+		
+		if (empty($rec['event_synopsis'])) {
+			$GLOBALS['am_error_log'][] = array('no_synopsis');
+		}
+		
+		if (empty($rec['event_venue'])) {
+			$GLOBALS['am_error_log'][] = array('no_venue');
+		}
 		
 		if (isset($data['event_private']) && !empty($data['event_private'])) {
 			$rec['event_private'] = 1;
@@ -168,15 +181,15 @@ class Event {
 		$rec['event_edit_datetime']   = time();
 		$rec['event_start_datetime']  = $this->timestamps['event_start_datetime'];
 		$rec['event_end_datetime']    = $this->timestamps['event_end_time'];
-		$rec['event_title']           = $data['event_title'];
-		$rec['event_synopsis']        = $data['event_synopsis'];
+		$rec['event_title']           = htmlspecialchars($data['event_title']);
+		$rec['event_synopsis']        = htmlspecialchars($data['event_synopsis']);
 		$rec['event_body']            = $data['event_body'];
 		$rec['location_id']           = $data['location_id'];
 		$rec['user_id']               = $this->user_id;
  		$rec['status_id']             = $this->event_config['event_invite_status'];
  		$rec['event_allocation']      = $data['event_allocation'];
 		$rec['level_id']              = $data['event_invite_type'];
-		$rec['event_venue']           = $data['event_venue'];
+		$rec['event_venue']           = htmlspecialchars($data['event_venue']);
 		$rec['language_id']           = $this->language_id;
 		
 		if (isset($data['file_id']) && $data['file_id'] != 0) {
@@ -231,9 +244,6 @@ class Event {
 		if (isset($result->fields)) {
 			$temp = $result->fields;
 			$result->Close();
-			if (isset($this->wiki)) {
-				$temp['event_body'] = $this->wiki->transform(stripslashes($temp['event_body']), 'Xhtml');
-			}
 			return $temp;
 		}
 		else {
@@ -267,16 +277,16 @@ class Event {
 			WHERE p.status_id=" . $this->event_config['user']['status']['active'] . " AND ";
 		}
 		else {
-			$t = "e";
-			$query .= ",l.location_name, i.identity_nic, i.identity_id, COUNT(p.user_id) AS count_attendance
-			FROM " . $this->db->prefix . "_event e
-			INNER JOIN " . $this->db->prefix . "_user_location l
-			ON l.location_id=e.location_id
-			LEFT JOIN " . $this->db->prefix . "_participation p
-			ON e.event_id=p.item_id
-			INNER JOIN " . $this->db->prefix . "_user_identity i
-			ON p.identity_id=i.identity_id
-			WHERE ";
+ 			$t = "e";
+ 			$query .= ",l.location_name, i.identity_nic, i.identity_id, COUNT(p.user_id) AS count_attendance
+ 			FROM " . $this->db->prefix . "_event e
+ 			LEFT JOIN " . $this->db->prefix . "_user_location l
+ 			ON l.location_id=e.location_id
+ 			LEFT JOIN " . $this->db->prefix . "_participation p
+ 			ON (e.event_id=p.item_id AND e.user_id=p.user_id)
+ 			INNER JOIN " . $this->db->prefix . "_user_identity i
+ 			ON p.identity_id=i.identity_id
+ 			WHERE ";
 		}
 		
 		if (isset($this->level_id)) {
@@ -296,6 +306,11 @@ class Event {
 			$query .= "UNIX_TIMESTAMP(e.event_start_datetime) < " . $timestamp_to . " AND ";
 		}
 		
+		if (isset($this->today)) {
+			$query .= "UNIX_TIMESTAMP(e.event_start_datetime) < " . $timestamp_from . " AND ";
+			$query .= "UNIX_TIMESTAMP(e.event_end_datetime) > " . $timestamp_from . " AND ";
+		}
+		
 		if ($my_events) {
 			$query .= $t . ".user_id=" . $this->user_id . " AND ";
 		}
@@ -310,10 +325,13 @@ class Event {
 		if (isset($this->high_attendance)) {
 			$query .= "ORDER BY count_attendance DESC, e.event_start_datetime";
 		}
+		elseif ($my_events) {
+			$query .= "ORDER BY e.event_create_datetime DESC";
+		}
 		else {
 			$query .= "ORDER BY e.event_start_datetime ";
 		}
-// echo $query; exit;
+
 		$result = $this->db->Execute($query);
 		
 		$temp = array();
@@ -325,11 +343,7 @@ class Event {
 			}
 		
 			while(!$result->EOF) {
-			
-				if (isset($this->wiki)) {
-					$result->fields['event_body'] = $this->wiki->transform(stripslashes($result->fields['event_body']), 'Xhtml');
-				}
-			
+
 				$result->fields['event_duration'] = $this->toDuration($result->fields['event_start_datetime'], $result->fields['event_end_datetime']);
 				array_push($temp, $result->fields);
 				$result->moveNext();
@@ -345,7 +359,7 @@ class Event {
 			}
 			$result->Close();
 		}
-		
+
 		if (isset($this->single_event)) {
 			if (isset($temp[0])) {
 				return $temp[0];
